@@ -17,7 +17,7 @@ var searchData=
   ['textinputtarget_14',['TextInputTarget',['../classTextInputTarget.html',1,'']]],
   ['textlayout_15',['TextLayout',['../classTextLayout.html',1,'']]],
   ['textpropertycomponent_16',['TextPropertyComponent',['../classTextPropertyComponent.html',1,'']]],
-  ['thiran_17',['Thiran',['../structdsp_1_1DelayLineInterpolationTypes_1_1Thiran.html',1,'dsp::DelayLineInterpolationTypes']]],
+  ['thiran_17',['Thiran',['../structjuce_1_1dsp_1_1DelayLineInterpolationTypes_1_1Thiran.html',1,'juce::dsp::DelayLineInterpolationTypes']]],
   ['thread_18',['Thread',['../classThread.html',1,'']]],
   ['threadedanalyticsdestination_19',['ThreadedAnalyticsDestination',['../classThreadedAnalyticsDestination.html',1,'']]],
   ['threadedwriter_20',['ThreadedWriter',['../classAudioFormatWriter_1_1ThreadedWriter.html',1,'AudioFormatWriter']]],
@@ -32,21 +32,25 @@ var searchData=
   ['timesliceclient_29',['TimeSliceClient',['../classTimeSliceClient.html',1,'']]],
   ['timeslicethread_30',['TimeSliceThread',['../classTimeSliceThread.html',1,'']]],
   ['togglebutton_31',['ToggleButton',['../classToggleButton.html',1,'']]],
-  ['tokentype_32',['TokenType',['../structCodeEditorComponent_1_1ColourScheme_1_1TokenType.html',1,'CodeEditorComponent::ColourScheme']]],
-  ['tonegeneratoraudiosource_33',['ToneGeneratorAudioSource',['../classToneGeneratorAudioSource.html',1,'']]],
-  ['toolbar_34',['Toolbar',['../classToolbar.html',1,'']]],
-  ['toolbarbutton_35',['ToolbarButton',['../classToolbarButton.html',1,'']]],
-  ['toolbaritemcomponent_36',['ToolbarItemComponent',['../classToolbarItemComponent.html',1,'']]],
-  ['toolbaritemfactory_37',['ToolbarItemFactory',['../classToolbarItemFactory.html',1,'']]],
-  ['toolbaritempalette_38',['ToolbarItemPalette',['../classToolbarItemPalette.html',1,'']]],
-  ['tooltipclient_39',['TooltipClient',['../classTooltipClient.html',1,'']]],
-  ['tooltipwindow_40',['TooltipWindow',['../classTooltipWindow.html',1,'']]],
-  ['toplevelwindow_41',['TopLevelWindow',['../classTopLevelWindow.html',1,'']]],
-  ['trackinfo_42',['TrackInfo',['../structGrid_1_1TrackInfo.html',1,'Grid']]],
-  ['trackproperties_43',['TrackProperties',['../structAudioProcessor_1_1TrackProperties.html',1,'AudioProcessor']]],
-  ['tracktionmarketplacestatus_44',['TracktionMarketplaceStatus',['../classTracktionMarketplaceStatus.html',1,'']]],
-  ['treeview_45',['TreeView',['../classTreeView.html',1,'']]],
-  ['treeviewitem_46',['TreeViewItem',['../classTreeViewItem.html',1,'']]],
-  ['typeface_47',['Typeface',['../classTypeface.html',1,'']]],
-  ['typehandler_48',['TypeHandler',['../classComponentBuilder_1_1TypeHandler.html',1,'ComponentBuilder']]]
+  ['tokenandid_32',['TokenAndId',['../structjuce_1_1midi__ci_1_1InitiatorPropertyExchangeCache_1_1TokenAndId.html',1,'juce::midi_ci::InitiatorPropertyExchangeCache']]],
+  ['tokentype_33',['TokenType',['../structCodeEditorComponent_1_1ColourScheme_1_1TokenType.html',1,'CodeEditorComponent::ColourScheme']]],
+  ['tolerance_34',['Tolerance',['../classTolerance.html',1,'']]],
+  ['tonegeneratoraudiosource_35',['ToneGeneratorAudioSource',['../classToneGeneratorAudioSource.html',1,'']]],
+  ['toolbar_36',['Toolbar',['../classToolbar.html',1,'']]],
+  ['toolbarbutton_37',['ToolbarButton',['../classToolbarButton.html',1,'']]],
+  ['toolbaritemcomponent_38',['ToolbarItemComponent',['../classToolbarItemComponent.html',1,'']]],
+  ['toolbaritemfactory_39',['ToolbarItemFactory',['../classToolbarItemFactory.html',1,'']]],
+  ['toolbaritempalette_40',['ToolbarItemPalette',['../classToolbarItemPalette.html',1,'']]],
+  ['tooltipclient_41',['TooltipClient',['../classTooltipClient.html',1,'']]],
+  ['tooltipwindow_42',['TooltipWindow',['../classTooltipWindow.html',1,'']]],
+  ['toplevelwindow_43',['TopLevelWindow',['../classTopLevelWindow.html',1,'']]],
+  ['tovar_44',['ToVar',['../classToVar.html',1,'']]],
+  ['tovaroptions_45',['ToVarOptions',['../classToVarOptions.html',1,'']]],
+  ['trackinfo_46',['TrackInfo',['../structGrid_1_1TrackInfo.html',1,'Grid']]],
+  ['trackproperties_47',['TrackProperties',['../structAudioProcessor_1_1TrackProperties.html',1,'AudioProcessor']]],
+  ['tracktionmarketplacestatus_48',['TracktionMarketplaceStatus',['../classTracktionMarketplaceStatus.html',1,'']]],
+  ['treeview_49',['TreeView',['../classTreeView.html',1,'']]],
+  ['treeviewitem_50',['TreeViewItem',['../classTreeViewItem.html',1,'']]],
+  ['typeface_51',['Typeface',['../classTypeface.html',1,'']]],
+  ['typehandler_52',['TypeHandler',['../classComponentBuilder_1_1TypeHandler.html',1,'ComponentBuilder']]]
 ];
