@@ -39,5 +39,6 @@ var searchData=
   ['format_36',['Format',['../structAudioData_1_1Format.html',1,'AudioData']]],
   ['fr_37',['Fr',['../structGrid_1_1Fr.html',1,'Grid']]],
   ['framerate_38',['FrameRate',['../classAudioPlayHead_1_1FrameRate.html',1,'AudioPlayHead']]],
-  ['fromvar_39',['FromVar',['../classFromVar.html',1,'']]]
+  ['fromvar_39',['FromVar',['../classFromVar.html',1,'']]],
+  ['functionblock_40',['FunctionBlock',['../structjuce_1_1midi__ci_1_1FunctionBlock.html',1,'juce::midi_ci']]]
 ];
