@@ -8,5 +8,6 @@ var searchData=
   ['popupdirection_5',['PopupDirection',['../classPopupMenu_1_1Options.html#a1bcdbc585618aba656891d7bd7e65b79',1,'PopupMenu::Options']]],
   ['priority_6',['priority',['../classThread.html#aae22d3d18dffe1adbbc2baf564e0383b',1,'Thread::Priority'],['../structPushNotifications_1_1Notification.html#a90a1b86b07e15d5cc253e904c66e8b70',1,'PushNotifications::Notification::Priority']]],
   ['processingprecision_7',['ProcessingPrecision',['../classAudioProcessor.html#a212c3670b59976559237cbf629af275f',1,'AudioProcessor']]],
-  ['processpriority_8',['ProcessPriority',['../classProcess.html#ad7b18ceb7a8c0a2b6b71856894feb6ef',1,'Process']]]
+  ['processpriority_8',['ProcessPriority',['../classProcess.html#ad7b18ceb7a8c0a2b6b71856894feb6ef',1,'Process']]],
+  ['propertysubscriptioncommand_9',['PropertySubscriptionCommand',['../namespacejuce_1_1midi__ci.html#a4ad367df239df26c74e25fec9ef60c46',1,'juce::midi_ci']]]
 ];
