@@ -1,13 +1,13 @@
 var searchData=
 [
   ['marketplace_0',['marketplace',['../group__juce__product__unlocking-marketplace.html',1,'']]],
-  ['maths_1',['maths',['../group__juce__core-maths.html',1,'(Global Namespace)'],['../group__juce__dsp-maths.html',1,'(Global Namespace)']]],
+  ['maths_1',['maths',['../group__juce__core-maths.html',1,'maths'],['../group__juce__dsp-maths.html',1,'maths']]],
   ['memory_2',['memory',['../group__juce__core-memory.html',1,'']]],
   ['menus_3',['menus',['../group__juce__gui__basics-menus.html',1,'']]],
   ['messages_4',['messages',['../group__juce__events-messages.html',1,'']]],
   ['midi_5',['midi',['../group__juce__audio__basics-midi.html',1,'']]],
   ['midi_5fio_6',['midi_io',['../group__juce__audio__devices-midi__io.html',1,'']]],
-  ['misc_7',['misc',['../group__juce__core-misc.html',1,'(Global Namespace)'],['../group__juce__gui__basics-misc.html',1,'(Global Namespace)'],['../group__juce__gui__extra-misc.html',1,'(Global Namespace)']]],
+  ['misc_7',['misc',['../group__juce__core-misc.html',1,'misc'],['../group__juce__gui__extra-misc.html',1,'misc'],['../group__juce__gui__basics-misc.html',1,'misc']]],
   ['mouse_8',['mouse',['../group__juce__gui__basics-mouse.html',1,'']]],
   ['mpe_9',['mpe',['../group__juce__audio__basics-mpe.html',1,'']]]
 ];
