@@ -4,7 +4,7 @@ var searchData=
   ['alerticontype_1',['AlertIconType',['../classAlertWindow.html#ac772713875db1d4038dd03f82d399df5',1,'AlertWindow']]],
   ['araanalysisprogressstate_2',['ARAAnalysisProgressState',['../classARAAudioSource.html#a270659f6f3b47903e78f2c9585b51ba9',1,'ARAAudioSource']]],
   ['arafactorycreationcallback_3',['ARAFactoryCreationCallback',['../classAudioPluginFormat.html#ab2cfc2bb23d9dbfc328d4048cb83ba1c',1,'AudioPluginFormat']]],
-  ['audioblocktype_4',['AudioBlockType',['../structdsp_1_1ProcessContextReplacing.html#aaa293a78b2efd11aec17ba8f67b5f466',1,'dsp::ProcessContextReplacing::AudioBlockType'],['../structdsp_1_1ProcessContextNonReplacing.html#a7cfdcc50ccc9e8bf85169600c0cbac08',1,'dsp::ProcessContextNonReplacing::AudioBlockType']]],
+  ['audioblocktype_4',['audioblocktype',['../structjuce_1_1dsp_1_1ProcessContextReplacing.html#af971e49569651113708189873deef4da',1,'juce::dsp::ProcessContextReplacing::AudioBlockType'],['../structjuce_1_1dsp_1_1ProcessContextNonReplacing.html#ab926d7a71c5e26224f0f11ee68c7d33a',1,'juce::dsp::ProcessContextNonReplacing::AudioBlockType']]],
   ['audiocomponentinstance_5',['AudioComponentInstance',['../group__juce__audio__processors-utilities.html#ga8d76a4b29adb5f5b39318dd91162b8f4',1,'juce_ExtensionsVisitor.h']]],
   ['audiosamplebuffer_6',['AudioSampleBuffer',['../group__juce__audio__basics-buffers.html#gab339ebab0d3b10c91c0d47c8fd2e50d2',1,'juce_AudioSampleBuffer.h']]],
   ['audiounit_7',['AudioUnit',['../group__juce__audio__processors-utilities.html#ga55e0e3a99e12b3f8e10f9125dc891709',1,'juce_ExtensionsVisitor.h']]]
