@@ -17,9 +17,9 @@ var searchData=
   ['acidtempo_14',['acidTempo',['../classWavAudioFormat.html#ac534d5f34f226b43dd6c03387f9aa9a5',1,'WavAudioFormat']]],
   ['action_15',['action',['../structPopupMenu_1_1Item.html#ac33ad5e4444e9215c8b4ab3a76a0243d',1,'PopupMenu::Item']]],
   ['actions_16',['actions',['../structPushNotifications_1_1Notification.html#a0a9804791528133bf6a31f293300e29e',1,'PushNotifications::Notification::actions'],['../structPushNotifications_1_1Settings_1_1Category.html#a9d683623a02780751a4ade7f0db55220',1,'PushNotifications::Settings::Category::actions']]],
-  ['active_17',['active',['../classIIRFilterBase.html#ad8b40797aa55fe60ac888e334a20ada1',1,'IIRFilterBase']]],
+  ['active_17',['active',['../classIIRFilterBase.html#ad8b40797aa55fe60ac888e334a20ada1',1,'IIRFilterBase::active'],['../structjuce_1_1midi__ci_1_1SupportedAndActive.html#a719e9af3f10793338b7116261f528eac',1,'juce::midi_ci::SupportedAndActive::active']]],
   ['adddefaultheader_18',['addDefaultHeader',['../structXmlElement_1_1TextFormat.html#a6c3d0ac316e68e5afab517c54b75386f',1,'XmlElement::TextFormat']]],
-  ['address_19',['address',['../classIPAddress.html#a2be5eab7b1b7d2e39d8d5367642f3004',1,'IPAddress::address'],['../structNetworkServiceDiscovery_1_1Service.html#ade832707345fb61ef8ed0332ef995ee9',1,'NetworkServiceDiscovery::Service::address']]],
+  ['address_19',['address',['../classIPAddress.html#a2be5eab7b1b7d2e39d8d5367642f3004',1,'IPAddress::address'],['../structNetworkServiceDiscovery_1_1Service.html#ade832707345fb61ef8ed0332ef995ee9',1,'NetworkServiceDiscovery::Service::address'],['../classjuce_1_1midi__ci_1_1ProfileAtAddress.html#a661a640730a8295417ae5a2b6ff3d2ab',1,'juce::midi_ci::ProfileAtAddress::address']]],
   ['alertonlyonce_20',['alertOnlyOnce',['../structPushNotifications_1_1Notification.html#ab134a2585ba8b5064397ed3c56202af0',1,'PushNotifications::Notification']]],
   ['aliceblue_21',['aliceblue',['../namespacejuce_1_1Colours.html#a8b5011b0c40b82f37eba4817bf7c21d3',1,'juce::Colours']]],
   ['aligncontent_22',['aligncontent',['../classFlexBox.html#a8e1ae8a873d7ff198f439d3088192bcf',1,'FlexBox::alignContent'],['../classGrid.html#a315d33b518dd1dc90068a51822b030ac',1,'Grid::alignContent']]],
@@ -49,9 +49,9 @@ var searchData=
   ['arafactory_46',['araFactory',['../structARAFactoryResult.html#a4a6e086542f278f6441fee94a8e616a2',1,'ARAFactoryResult']]],
   ['area_47',['area',['../classGridItem.html#aa1d3cb3665477cdb7b58a607b779f8f3',1,'GridItem']]],
   ['argumentdescription_48',['argumentDescription',['../structConsoleApplication_1_1Command.html#a58d4d1dcda368f079ea7f648e89349a2',1,'ConsoleApplication::Command']]],
-  ['arguments_49',['arguments',['../structvar_1_1NativeFunctionArgs.html#a6c898b57ab92fb3084a78a4713ae2065',1,'var::NativeFunctionArgs::arguments'],['../structArgumentList.html#aebbb44f0cabf89cc672536887be82915',1,'ArgumentList::arguments']]],
-  ['ascent_50',['ascent',['../classCustomTypeface.html#ab5c74224ec102b6990481b658d189ac4',1,'CustomTypeface::ascent'],['../classTextLayout_1_1Line.html#ac356b4c8bd159161ac80438457471d7d',1,'TextLayout::Line::ascent']]],
-  ['associatedcomponent_51',['associatedcomponent',['../classGridItem.html#a5c2e9d897bcb5530d598aff2f910371a',1,'GridItem::associatedComponent'],['../classFlexItem.html#a844775f34c346b8e807c66d3623d9ea8',1,'FlexItem::associatedComponent']]],
+  ['arguments_49',['arguments',['../structArgumentList.html#aebbb44f0cabf89cc672536887be82915',1,'ArgumentList::arguments'],['../structvar_1_1NativeFunctionArgs.html#a6c898b57ab92fb3084a78a4713ae2065',1,'var::NativeFunctionArgs::arguments']]],
+  ['ascent_50',['ascent',['../classTextLayout_1_1Line.html#ac356b4c8bd159161ac80438457471d7d',1,'TextLayout::Line::ascent'],['../classCustomTypeface.html#ab5c74224ec102b6990481b658d189ac4',1,'CustomTypeface::ascent']]],
+  ['associatedcomponent_51',['associatedcomponent',['../classFlexItem.html#a844775f34c346b8e807c66d3623d9ea8',1,'FlexItem::associatedComponent'],['../classGridItem.html#a5c2e9d897bcb5530d598aff2f910371a',1,'GridItem::associatedComponent']]],
   ['associatedflexbox_52',['associatedFlexBox',['../classFlexItem.html#ae91dba1ed2ad5a26f0b2733060dbd5ac',1,'FlexItem']]],
   ['aswgaccent_53',['aswgAccent',['../classWavAudioFormat.html#adef504fcd90bd4f2fe8dd162c8b44090',1,'WavAudioFormat']]],
   ['aswgactorgender_54',['aswgActorGender',['../classWavAudioFormat.html#a1dcebe466a57971170eab681cb529f6a',1,'WavAudioFormat']]],
